@@ -23,9 +23,9 @@
 #define CONFIGLIST_H
 
 //TQt header
-#include <ntqptrlist.h>
-#include <ntqlistview.h>
-#include <ntqobject.h>
+#include <tqptrlist.h>
+#include <tqlistview.h>
+#include <tqobject.h>
 
 //KDE headers
 #include <kcombobox.h>
@@ -602,7 +602,7 @@ class ConfigList : public TQObject, public TQPtrList<ConfigElem>
      * @param item account object
      * @return pointer to the new account object
      */
-    virtual TQCollection::Item newItem( TQCollection::Item item );
+    virtual TQPtrCollection::Item newItem( TQPtrCollection::Item item );
 
     /**
      * Compares two ConfigElem objects.
@@ -612,7 +612,7 @@ class ConfigList : public TQObject, public TQPtrList<ConfigElem>
      * @return 0 if account name 1 == account name 2
      * @return nonzero if account name 2 != account name 2
      */
-    virtual int compareItems( TQCollection::Item item1, TQCollection::Item item2 );
+    virtual int compareItems( TQPtrCollection::Item item1, TQPtrCollection::Item item2 );
 
     /**
      * Returns whether the given account is in the list
